@@ -5,7 +5,7 @@ Most, but not all, features of this module work with CouchDB version < 2.0.
 Relies on requests: http://docs.python-requests.org/en/master/
 """
 
-__version__ = "1.9.0"
+__version__ = "1.9.2"
 
 # Standard packages
 import argparse
@@ -34,17 +34,22 @@ class Server(object):
     "A connection to the CouchDB server."
 
     def __init__(self, href="http://localhost:5984/",
-                 username=None, password=None, use_session=True):
+                 username=None, password=None, use_session=True, ca_file=None):
         """Connect to the CouchDB server.
 
         If `use_session` is true, then an authenticated CouchDB session
         is used transparently.
 
         Otherwise, username and password is sent with each request.
+
+        `ca_file` can point to a file or a directory containing CAs if
+        you need to access databases in HTTPS.
         """
         self.href = href.rstrip("/") + "/"
         self._session = requests.Session()
         self._session.headers.update({"Accept": JSON_MIME})
+        if ca_file is not None:
+            self._session.verify = ca_file
         if username and password:
             if use_session:
                 self._POST("_session",
@@ -368,15 +373,20 @@ class Database(object):
         """
         self.server._POST(self.name, "_view_cleanup")
 
-    def get(self, id, rev=None, revs_info=False, default=None):
+    def get(self, id, rev=None, revs_info=False, default=None, conflicts=False):
         """Return the document with the given id,
         or the `default` value if not found.
+
+        If conflicts is True, includes information about conflicts in document
+        (in `_conflicts` attribute).
         """
         params = {}
         if rev is not None:
             params["rev"] = rev
         if revs_info:
             params["revs_info"] = jsons(True)
+        if conflicts:
+            params['conflicts'] = jsons(True)
         response = self.server._GET(self.name, id, errors={404: None},
                                     params=params)
         if response.status_code == 404:
@@ -631,12 +641,15 @@ class Database(object):
         self.server._DELETE(self.name, "_index", ddoc, "json", name)
 
     def find(self, selector, limit=None, skip=None, sort=None, fields=None, 
-             use_index=None, bookmark=None, update=None):
+             use_index=None, bookmark=None, update=None, conflicts=None):
         """Select documents according to the selector.
 
         Returns a dictionary with items `docs`, `warning`, `execution_stats`
         and `bookmark`.
 
+        If conflicts is True, includes information about conflicts in documents
+        (in `_conflicts` attribute).
+
         CouchDB version >= 2.0.
         """
         assert self.server.version >= "2.0"
@@ -655,6 +668,8 @@ class Database(object):
             doc["bookmark"] = bookmark
         if update is not None:
             doc["update"] = update
+        if conflicts is not None:
+            doc['conflicts'] = conflicts
         return jsonod(self.server._POST(self.name, "_find", json=doc))
 
     def explain(self, selector, limit=None, skip=None, sort=None, fields=None,
@@ -942,6 +957,8 @@ def get_parser():
     x01.add_argument("-p", "--password", help="CouchDB user account password")
     x01.add_argument("-q", "--password_question", action="store_true",
                      help="ask for the password by interactive input")
+    p.add_argument("--ca_file", metavar="FILEORDIRPATH",
+                   help="file or directory containing CAs")
     p.add_argument("-o", "--output", metavar="FILEPATH",
                    help="write output to the given file (JSON format)")
     p.add_argument("--indent", type=int, metavar="INT",
@@ -1166,7 +1183,8 @@ def execute(pargs, settings):
     "Execution of the CouchDB2 command line tool."
     server = Server(href=settings["SERVER"],
                     username=settings["USERNAME"],
-                    password=settings["PASSWORD"])
+                    password=settings["PASSWORD"],
+                    ca_file=pargs.ca_file)
     if pargs.verbose and server.user_context:
         print("User context:", jsons(server.user_context, indent=2))
     if pargs.version:
